@@ -24,8 +24,6 @@ sub jedi_app {
 
     $jedi->get( '/cookie', $jedi->can('handle_cookies') );
 
-    $jedi->get( '/jedi_env', $jedi->can('handle_jedi_env') );
-
     $jedi->get( '/scheme', $jedi->can('handle_scheme') );
     $jedi->get( '/host',   $jedi->can('handle_host') );
     $jedi->get( '/port',   $jedi->can('handle_port') );
@@ -59,14 +57,6 @@ sub handle_cookies {
     return 1;
 }
 
-sub handle_jedi_env {
-    my ( $jedi, $request, $response ) = @_;
-    $jedi->clear_jedi_env;
-    $response->status(200);
-    $response->body( $jedi->jedi_env );
-    return 1;
-}
-
 sub handle_scheme {
     my ( $jedi, $request, $response ) = @_;
     $response->status(200);
